BrandGoodslist class
- Annotations
-
- @freezed
Constructors
- BrandGoodslist({@Default.new(0) num activitytype, @Default.new(0) num actualprice, @Default.new('') String brandid, @Default.new(0) num cid, @Default.new(0) num commissionrate, @Default.new(0) num commissiontype, @Default.new('') String couponconditions, @Default.new('') String couponendtime, @Default.new('') String couponid, @Default.new('') String couponlink, @Default.new(0) num couponprice, @Default.new(0) num couponreceivenum, @Default.new('') String couponstarttime, @Default.new(0) num coupontotalnum, @Default.new('') String dtitle, @Default.new(0) num dailysales, @Default.new('') String desc, @Default.new(0) num discount, @Default.new(0) num flagshipstore, @Default.new(0) num freeshipremotedistrct, @Default.new('') String goodsid, @Default.new('') String goodssign, @Default.new(0) num id, @Default.new('') String mainpic, @Default.new('') String marketingmainpic, @Default.new(0) num monthsales, @Default.new(0) num originprice, @Default.new([]) List specialtext, @Default.new('') String title, @Default.new('') String video})
-
constfactory
-
BrandGoodslist.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activitytype → num
-
no setterinherited
- actualprice → num
-
no setterinherited
- brandid → String
-
no setterinherited
- cid → num
-
no setterinherited
- commissionrate → num
-
no setterinherited
- commissiontype → num
-
no setterinherited
-
copyWith
→ $BrandGoodslistCopyWith<
BrandGoodslist> -
no setterinherited
- couponconditions → String
-
no setterinherited
- couponendtime → String
-
no setterinherited
- couponid → String
-
no setterinherited
- couponlink → String
-
no setterinherited
- couponprice → num
-
no setterinherited
- couponreceivenum → num
-
no setterinherited
- couponstarttime → String
-
no setterinherited
- coupontotalnum → num
-
no setterinherited
- dailysales → num
-
no setterinherited
- desc → String
-
no setterinherited
- discount → num
-
no setterinherited
- dtitle → String
-
no setterinherited
- flagshipstore → num
-
no setterinherited
- freeshipremotedistrct → num
-
no setterinherited
- goodsid → String
-
no setterinherited
- goodssign → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → num
-
no setterinherited
- mainpic → String
-
no setterinherited
- marketingmainpic → String
-
no setterinherited
- monthsales → num
-
no setterinherited
- originprice → num
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specialtext → List
-
no setterinherited
- title → String
-
no setterinherited
- video → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited